@@ -21,14 +21,14 @@ def finditem(func, seq):
 # http://stackoverflow.com/questions/749796/pretty-printing-xml-in-python
 # http://effbot.org/zone/element-lib.htm#prettyprint
 def _indent(elem, level=0):
-    i = "\n" + level*"  "
+    i = "\n" + level * "  "
     if len(elem):
         if not elem.text or not elem.text.strip():
             elem.text = i + "  "
         if not elem.tail or not elem.tail.strip():
             elem.tail = i
         for elem in elem:
-            _indent(elem, level+1)
+            _indent(elem, level + 1)
         if not elem.tail or not elem.tail.strip():
             elem.tail = i
     else:
@@ -45,10 +45,11 @@ def _ds(elem):
     _indent(elem)
     return ElementTree.tostring(elem)
 
+
 def numericise(value, empty2zero=False):
     """Returns a value that depends on the input string:
         - Float if input can be converted to Float
-        - Integer if iinputt can be converted to integer
+        - Integer if input can be converted to integer
         - Zero if the input string is empty and empty2zero flag is set
         - The same input string, empty or not, otherwise.
 
@@ -66,24 +67,27 @@ def numericise(value, empty2zero=False):
     ''
     >>> numericise("")
     ''
+    >>> numericise(None)
     >>>
     """
-
-    try:
-        value = int(value)
-    except ValueError:
-        try: 
-            value = float(value)
+    if value is not None:
+        try:
+            value = int(value)
         except ValueError:
-            if value == "" and empty2zero == True: 
-                value = 0
-                
+            try:
+                value = float(value)
+            except ValueError:
+                if value == "" and empty2zero:
+                    value = 0
+
     return value
 
+
 def numericise_all(input, empty2zero=False):
     """Returns a list of numericised values from strings"""
     return [numericise(s, empty2zero) for s in input]
 
+
 if __name__ == '__main__':
     import doctest
-    doctest.testmod()
\ No newline at end of file
+    doctest.testmod()
